%define _disable_ld_no_undefined 1
%define upstream_name hts-tvheadend

Name:           tvheadend
Summary:        TV streaming server
Version:        2.12
Release:        %mkrel 4
License:        GPLv3
URL:            http://www.lonelycoder.com
Group:          Video
Source0:        %{upstream_name}_%{version}.tar.gz
Source1:        %{name}.init
Source2:        %{name}.png
Source3:        %{name}.start
Source4:        %{name}.conf
Source5:        README.urpmi
Patch0:         %{name}-2.12-i586-cflags.patch
BuildRequires:  kdelibs4-devel qt4-devel avahi-client-devel libgcrypt-devel

Requires:       pwgen
Requires(pre):  rpm-helper
Requires(preun):rpm-helper

%description
Tvheadend is a TV streaming server for Linux supporting DVB-S, DVB-S2, DVB-C,
DVB-T, ATSC, IPTV, and Analog video (V4L) as input sources.

For the full list of features see the documentation on:
https://www.lonelycoder.com/hts/tvheadend/docs/2_12/index.html

%prep
%setup -q -n %{upstream_name}-%{version}
iconv -f iso8859-1 -t utf-8 README -o README
%ifarch %{ix86}
%patch0 -p0 -b .i586-cflags
%endif

%build
%ifarch %{ix86}
./configure --prefix=/usr --release --cpu=pentium4 --libdir=%{_libdir}
%else
./configure --prefix=/usr --release --libdir=%{_libdir}
%endif
%make

%install
rm -rf %{buildroot}
%makeinstall_std

#create the default documentation directory and put the READMI.urpmi file into it
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}
cp -v %{SOURCE5} .
iconv -f iso8859-1 -t utf-8 README.urpmi -o README.urpmi

#create the manpage directory and compress the manpage into it
mkdir -p %{buildroot}/%{_mandir}1
lzma %{buildroot}/%{_mandir}1/%{name}.1

#create the home directory and copy the config file into it
mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol
cp -v %{SOURCE4} %{buildroot}%{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1

#create the binary directory and copy the application laucher startup script into it
mkdir -p %{buildroot}/%{_bindir}
cp -v %{SOURCE3} %{buildroot}/%{_bindir}/%{name}.start

#create the icon directory and copy the application launcher icon into it
mkdir -p %{buildroot}/%{_iconsdir}
cp -v %{SOURCE2} %{buildroot}/%{_iconsdir}/%{name}.png

#create the application launcher directory and put the desktop file into it
mkdir -p %{buildroot}/%{_datadir}/applications
cat > %{buildroot}/%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Tvheadend
Comment=%{summary}
Exec=%{_bindir}/%{name}.start
Icon=%{_iconsdir}/%{name}.png
Type=Application
Categories=AudioVideo;Video;TV;Recorder;
EOF

#create the daemon directory and copy the init script into it
mkdir -p %{buildroot}/%{_initddir}
cp -v %{SOURCE1} %{buildroot}/%{_initddir}/%{name}

%pre
#create a user including a home directory and make him a member of the video group
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /sbin/nologin
usermod -G video %{name}

%post
#change the owner and group of the created home directory
chown %{name}:root %{_localstatedir}/lib/%{name} 
cd %{_localstatedir}/lib/%{name}
chown -R %{name}:video .hts*

#replace the "dummypassword" with a pwgen generated password 
sed -i s/dummypassword/$(pwgen -s 12 1)/g %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1
%_post_service %{name}

%preun
%_preun_service %{name}

%clean
rm -rf %{buildroot}

%files
%defattr(0644, root, root, 0755)
%doc debian/changelog LICENSE README
%doc README.urpmi
%attr(0755, root, root) %{_bindir}/%name
%attr(0755, root, root) %{_bindir}/%name.start
%attr(0755, root, root) %{_initddir}/%name
%attr(0644, root, root) %{_mandir}1/%name.1.lzma
%attr(0644, root, root) %{_iconsdir}/%name.png
%attr(0644, root, root) %{_datadir}/applications/%{name}.desktop

#home directory and config file 
%dir %attr(-,tvheadend,root) %{_localstatedir}/lib/%{name}
%dir %attr(-,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol
%attr(0600,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1

%changelog
* Mon Dec 12 2011 #shadow# <rpm-mud@arcor.de> 2.12-4mud2010.2
- add automatic generated user password with pwgen

* Tue Dec 07 2011 #shadow# <rpm-mud@arcor.de> 2.12-4mud2010.2
- add config file with login datas
- rework the readme.urpmi file

* Tue Sep 27 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- rework the menu start script, fix the start problem

* Tue Sep 27 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- add readme.urpmi file 

* Mon Sep 26 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- add reload function to init script

* Sun Sep 18 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- add menu entry based on tamplate from doktor5000

* Sun Sep 18 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- converting not utf-8 compatible readme file 

* Sun Sep 18 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- compress manpage with lzma due to faulty installation

* Sat Aug 13 2011 #shadow# <rpm-mud@arcor.de> 2.12-2mud2010.2
- add init script taken from clearos tvheadend package

* Sat Aug 13 2011 #shadow# <rpm-mud@arcor.de> 2.12-2mud2010.2
- add patch0 taken from doktor5000 to fix i586 build problem

* Sun Aug 07 2011 #shadow# <rpm-mud@arcor.de> 2.12-1mud2010.2
- build initial tvheadend-package
